cmomy.xCentralMoments
=====================

.. currentmodule:: cmomy

.. autoclass:: xCentralMoments
   :show-inheritance:

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: 
   
      ~xCentralMoments.__init__
      ~xCentralMoments.assign_attrs
      ~xCentralMoments.assign_coords
      ~xCentralMoments.block
      ~xCentralMoments.cmom
      ~xCentralMoments.copy
      ~xCentralMoments.fill
      ~xCentralMoments.from_data
      ~xCentralMoments.from_datas
      ~xCentralMoments.from_raw
      ~xCentralMoments.from_raws
      ~xCentralMoments.from_resample_vals
      ~xCentralMoments.from_stat
      ~xCentralMoments.from_stats
      ~xCentralMoments.from_vals
      ~xCentralMoments.isel
      ~xCentralMoments.mean
      ~xCentralMoments.moveaxis
      ~xCentralMoments.new_like
      ~xCentralMoments.push_data
      ~xCentralMoments.push_datas
      ~xCentralMoments.push_stat
      ~xCentralMoments.push_stats
      ~xCentralMoments.push_val
      ~xCentralMoments.push_vals
      ~xCentralMoments.reduce
      ~xCentralMoments.rename
      ~xCentralMoments.resample
      ~xCentralMoments.resample_and_reduce
      ~xCentralMoments.reshape
      ~xCentralMoments.rmom
      ~xCentralMoments.sel
      ~xCentralMoments.stack
      ~xCentralMoments.std
      ~xCentralMoments.to_raw
      ~xCentralMoments.transpose
      ~xCentralMoments.var
      ~xCentralMoments.weight
      ~xCentralMoments.zero
      ~xCentralMoments.zeros
      ~xCentralMoments.zeros_like
   
   

   
   
   .. rubric:: Attributes
   
   .. autosummary::
      :toctree: 
   
      ~xCentralMoments.attrs
      ~xCentralMoments.coords
      ~xCentralMoments.data
      ~xCentralMoments.dims
      ~xCentralMoments.dtype
      ~xCentralMoments.indexes
      ~xCentralMoments.mom
      ~xCentralMoments.mom_dims
      ~xCentralMoments.mom_ndim
      ~xCentralMoments.mom_shape
      ~xCentralMoments.mom_shape_var
      ~xCentralMoments.name
      ~xCentralMoments.ndim
      ~xCentralMoments.shape
      ~xCentralMoments.shape_flat
      ~xCentralMoments.shape_flat_var
      ~xCentralMoments.shape_var
      ~xCentralMoments.sizes
      ~xCentralMoments.val_dims
      ~xCentralMoments.val_ndim
      ~xCentralMoments.val_shape
      ~xCentralMoments.val_shape_flat
      ~xCentralMoments.values
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree: 
   
      ~xCentralMoments.__add__
      ~xCentralMoments.__iadd__
      ~xCentralMoments.__imul__
      ~xCentralMoments.__isub__
      ~xCentralMoments.__mul__
      ~xCentralMoments.__repr__
      ~xCentralMoments.__sub__
   
   